@@ -8,5 +8,11 @@ class NothingFoundError(Exception):
     def __init__(self,Note:str=""):
         pass
 class DummyError(Exception):
+    def __init__(self,Note:str=""):
+        pass
+class NotImplemented(Exception):
+    def __init__(self,Note:str=""):
+        pass
+class NotActivated(Exception):
     def __init__(self,Note:str=""):
         pass
\ No newline at end of file
