@@ -1,4 +1,6 @@
 import multiprocessing,os,mediapipe
+from . import Discord_framework
+__ext_DCF__ = False
 class using:
     def create_process(target,args):
         p = multiprocessing.Process(target=target,args=args)
@@ -42,6 +44,18 @@ class Q:
     build_hex = 'id?hex='
     build_rgb = 'id?rgb=rgb'
     urlSafeChars=".","\\","(",")","{","[","|","]","}","^",">","<"
+class ScannedText:
+    def __init__(self,res1,res2,img_dat1,img_dat2):
+        self.ext_text = res2
+        self.raw_boxes = res1
+        self.height = img_dat2
+        self.width = img_dat1
+        I = []
+        for b in self.raw_boxes.splitlines():
+            b = b.split(' ')
+            i = int(b[1]),int(b[2]),int(b[3]),int(b[4]),str(b[0])
+            I.append(i)
+        self.boxes = I
 class Hand:
     def __init__(self,n_hand:int,lm:list,handLms):
         self.hand_n             = n_hand
@@ -131,4 +145,18 @@ class Face:
         self.results = res
         self.conf_score = score
         self.bbox = bbox
-        self.ext_lms = lm_list
\ No newline at end of file
+        self.ext_lms = lm_list
+if __ext_DCF__ == True:
+    class DCF:
+        Send = Discord_framework.send
+        Friends = Discord_framework.friends
+        Info = Discord_framework.info
+        Token = Discord_framework.token
+        All = Discord_framework
+else:
+    class DCF:
+        Send = None
+        Friends = None
+        Info = None
+        Token = None
+        All = None
\ No newline at end of file
