@@ -1,4 +1,6 @@
 import cv2,mediapipe,time,keyboard,numpy
+import pytesseract.pytesseract
+import tesseract_pack
 from .parse import *
 class Utils:
     def absa(c1:tuple,c2:tuple,t:int):
@@ -222,7 +224,7 @@ class Gestures:
         else:
             return False
 class Segmentation:
-    def __init__(self,rep_img,rem_perc:float,model_sel=0):
+    def __init__(self,rep_img,rem_perc:float,model_sel=0,body=False):
         """
         rep_img is the replacement for the background.
         rem_perc is the percentage of the background that gets deleted (0.85 is good)
@@ -231,22 +233,46 @@ class Segmentation:
         self.rem = rem_perc
         self.replace_img = rep_img
         self.mode_sel = model_sel
+        self.bod = body
         self.model = mediapipe.solutions.selfie_segmentation.SelfieSegmentation(self.mode_sel)
     def segment(self,img):
         """
         The given background Image must be the same size as the normal Image
         """
         imgRGB = cv2.cvtColor(img, cv2.COLOR_BGR2RGB)
-        results = self.model.process(imgRGB)
-        condition = numpy.stack(
-            (results.segmentation_mask,) * 3, axis=-1) > self.rem
+        results = self.model.process(imgRGB) # Create a black-white image
+        if self.bod:
+            condition = numpy.stack((results.segmentation_mask,) * 3, axis=-1) < self.rem
+        else:                                                                               # Apply rem_perc
+            condition = numpy.stack((results.segmentation_mask,) * 3, axis=-1) > self.rem
         if isinstance(self.replace_img, tuple):
             _imgBg = numpy.zeros(img.shape, dtype=numpy.uint8)
-            _imgBg[:] = self.replace_img
+            _imgBg[:] = self.replace_img                             # Make the background
             imgOut = numpy.where(condition, img, _imgBg)
         else:
-            imgOut = numpy.where(condition, img, self.replace_img)
+            imgOut = numpy.where(condition, img, self.replace_img) # Combine both
         return imgOut
+class TextRecognition:
+    def __init__(self,img):
+        self.def_img = img
+        self.IMG = cv2.cvtColor(img,cv2.COLOR_BGR2RGB)
+        self.shape = self.IMG.shape
+        tmp_hIMG,tmp_wImg,ust = self.shape
+        self.hIMG = tmp_hIMG
+        self.wIMG =tmp_wImg
+        tox = '\\'
+        self.install = (f'{tesseract_pack.data_here.replace(tox,"/")}\\tesseract.exe') # tesseract_pack.data_here is the location of tesseract, it is used, so it does not have to be installed manually
+    def get_data(self):
+        pytesseract.pytesseract.tesseract_cmd = self.install
+        result1 = pytesseract.pytesseract.image_to_boxes(self.IMG)
+        result2 = pytesseract.pytesseract.image_to_string(self.IMG)
+        obj = ScannedText(result1,result2,self.hIMG,self.wIMG)
+        return obj
+    def draw_all(self,obj:ScannedText):
+        img = self.def_img
+        for b in obj.boxes:
+            cv2.rectangle(img,(b[0],obj.height-b[1]),(b[2],obj.height-b[3]),(0,0,255),3)
+        return img
 class Examples:
     def SPS(input=1,quit_key='esc'):
         """
